
from flask_wtf import FlaskForm
from flask_login import current_user
from wtforms import StringField, SubmitField, StringField, BooleanField, SelectField, IntegerField, FloatField, PasswordField, FileField, HiddenField, form
from wtforms.validators import InputRequired, ValidationError, DataRequired, Length, EqualTo, Required, Length, Email, Regexp, EqualTo, URL, Optional, NumberRange
from app.models import User, ROLES
from wtforms.fields.html5 import DateField

class EditProfileForm(FlaskForm):
    username = StringField('Username', validators=[Length(min=3, max=32)], render_kw={"class": ""})
    email = StringField('Email', validators=[Length(min=6, max=40)])
    first_name = StringField('First name', validators=[Length(min=1, max=32)])
    last_name = StringField('Last name', validators=[Length(min=1, max=32)])
    submit = SubmitField('Submit')



    def __init__(self, original_username, *args, **kwargs):
        super(EditProfileForm, self).__init__(*args, **kwargs)
        self.original_username = original_username

    def validate_username(self, username):
        if username.data != self.original_username:
            user = User.query.filter_by(username=self.username.data).first()
            if user is not None:
                raise ValidationError('Please use a different username.')


class EditUserForm(FlaskForm):
    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)
        self.role.choices = [r[0] for r in ROLES]

    username = StringField('Username', validators=[Length(min=3, max=32)])
    email = StringField('Email', validators=[Length(min=6, max=40)])
    email_confirmed_at = StringField('Date email was confirmed ')
    first_name = StringField('First name', validators=[Length(min=1, max=32)])
    last_name = StringField('Last name', validators=[Length(min=1, max=32)])
    active = BooleanField("User is active?", default=False)
    is_disabled = BooleanField("Disable user?", default=False)
    role = SelectField("User role")

    submit = SubmitField('Submit')


class NewUserForm(FlaskForm):
    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)
        self.role.default = "driver"
        self.role.choices = [r[0] for r in ROLES]

    username = StringField('Username', validators=[Length(min=3, max=32)])
    email = StringField('Email', validators=[Length(min=6, max=40)])
    password = PasswordField('Password', validators=[DataRequired()])
    password2 = PasswordField('Repeat Password', validators=[DataRequired(), EqualTo('password')])
    first_name = StringField('First name', validators=[Length(min=1, max=32)])
    last_name = StringField('Last name', validators=[Length(min=1, max=32)])
    role = SelectField("User role")

    submit = SubmitField('Submit')


class AdminResetPasswordForm(FlaskForm):
    password = PasswordField('Password', validators=[DataRequired()])
    password2 = PasswordField('Repeat Password', validators=[DataRequired(), EqualTo('password')])
    submit = SubmitField('Reset password')


class EditLandlordForm(FlaskForm):
    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)


    address = StringField('Address', validators=[])
    city = StringField('City', default="Calgary")
    province = StringField('Province', default="Alberta")
    postal_code = StringField('Postal Code', validators=[])
    equifax_token = StringField('Equifax Token', validators=[])
    submit = SubmitField('Submit')


class NewPropertyForm(FlaskForm):
    address = StringField('Address')
    city = StringField('City', default="Calgary")
    province = StringField('Province', default="Calgary")
    postal_code = StringField('Postal Code')
    rent_cost = FloatField("Rent Amount", validators=[InputRequired(), NumberRange(min=0)])
    # rent_due = DateField("Rent Due", format='%Y-%m-%d', validators=[])
    lease_agreement = FileField('Upload Lease')
    active = BooleanField("Active")
    submit = SubmitField('Submit')


class EditPropertyForm(FlaskForm):
    address = StringField('Address', validators=[])
    city = StringField('City', validators=[], default="Calgary")
    province = StringField('Province')
    postal_code = StringField('Postal Code', validators=[])
    rent_cost = FloatField("Rent Amount", validators=[InputRequired(), NumberRange(min=0)])
    # rent_due = DateField("Rent Due", format='%Y-%m-%d', validators=[])
    lease_agreement = FileField('Upload Lease', validators=[])
    is_active = BooleanField("Active")
    submit = SubmitField('Submit')


class NewTenantForm(FlaskForm):
    first_name = StringField('Given name', validators=[])
    last_name = StringField('Surname', validators=[])
    email = StringField('Email', validators=[])
    telephone = StringField('Phone #', validators=[])
    address = StringField('Address', validators=[])
    city = StringField('City', validators=[], default="Calgary")
    province = StringField('Province', validators=[], default="Alberta")
    postal_code = StringField('Postal Code', validators=[])
    lease_agreement = FileField('Upload Lease', validators=[])
    is_active = BooleanField("Active")
    submit = SubmitField('Submit')


class EditTenantForm(FlaskForm):
    first_name = StringField('Given name', validators=[])
    last_name = StringField('Surname', validators=[])
    email = StringField('Email', validators=[])
    telephone = StringField('Phone #', validators=[])
    address = StringField('Address', validators=[])
    city = StringField('City', validators=[], default="Calgary")
    province = StringField('Province', validators=[], default="Alberta")
    postal_code = StringField('Postal Code', validators=[])
    lease_agreement = FileField('Upload Lease', validators=[])
    is_active = BooleanField("Active")
    submit = SubmitField('Submit')


class NewLinkForm(FlaskForm):
    # def __init__(self, *args, **kwargs):
    #     super().__init__(*args, **kwargs)


    tenant = SelectField('Tenant', coerce=str, )
    lease_upload = FileField("Upload lease / Contract")
    submit = SubmitField('Submit')


class EditLinkForm(FlaskForm):
    tenant = SelectField('Username', validators=[Length(min=3, max=32)])
    property = StringField('Email', validators=[Length(min=6, max=40)])
    date_paid = PasswordField('Password', validators=[DataRequired()])
    is_on_time = PasswordField('Repeat Password', validators=[DataRequired(), EqualTo('password')])
    amount = StringField('First name', validators=[Length(min=1, max=32)])
    submit = SubmitField('Submit')


class ReportRentForm(FlaskForm):
    date_paid = DateField('Date paid', validators=[])
    is_on_time = BooleanField('Rent paid on time?', validators=[])
    amount = IntegerField("Rent Amount", validators=[])
    submit = SubmitField('Submit')




class EmptyForm(FlaskForm):
    submit = SubmitField('Submit')

